import { Message } from "npm:ollama@0.5.15"

export class History {
	private constructor(
		public messages: Message[],
		private path: string,
		private limit: number,
	) {}

	public push(value: Message) {
		this.messages.push(value)
		while (this.messages.length > this.limit) this.messages.splice(0, 1)
	}

	public static async load(path: string, limit: number) {
		try {
			const content = await Deno.readTextFile(path)
			const { messages } = JSON.parse(content)
			return new History(messages, path, limit)
		} catch (except) {
			console.error("Failed to load spilling queue :", except)
			return undefined
		}
	}

	public static async create(path: string, limit: number) {
		const result = new History([], path, limit)
		await result.save()
		return result
	}

	private async save() {
		await Deno.writeTextFile(this.path, JSON.stringify({ messages: this.messages }))
	}
}
